@@ -1,5 +1,5 @@
 api_key = None
 client_id = None
-api_base = 'https://internalapi.senddots.com/api'
+api_base = 'https://pls.senddots.com/api'
 
 from dots.invoice import Invoice
\ No newline at end of file
